@@ -8,7 +8,7 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
@@ -62,7 +62,7 @@ public:
 	const char* failure_message(void) const { return message(); }
 
 	/** @private */
-	operator bool (void)	const	{ return m_result; }
+	IUTEST_CXX_EXPLICIT_CONVERSION operator bool (void)	const	{ return m_result; }
 
 public:
 	/**
@@ -156,9 +156,9 @@ public:
 private:
 	IUTEST_PP_DISALLOW_COPY_AND_ASSIGN(AssertionHelper);
 
-#if IUTEST_HAS_RVALUE_REFS && IUTEST_HAS_DELETED_FUNCTIONS
-	AssertionHelper(AssertionHelper&& rhs) = delete;
-	AssertionHelper& operator=(AssertionHelper&&) = delete;
+#if IUTEST_HAS_RVALUE_REFS
+	AssertionHelper(AssertionHelper&& rhs) IUTEST_DECL_DELETED_FUNCTION;
+	AssertionHelper& operator=(AssertionHelper&&) IUTEST_DECL_DELETED_FUNCTION;
 #endif
 
 public:
@@ -166,7 +166,7 @@ public:
 	void	operator = (const Fixed& fixed)
 	{
 		OnFixed(fixed);
-#if IUTEST_HAS_EXCEPTIONS && IUTEST_THROW_ON_ASSERT_FAILURE
+#if IUTEST_HAS_EXCEPTIONS && IUTEST_USE_THROW_ON_ASSERT_FAILURE
 		{
 			if( m_part_result.type() == TestPartResult::kFatalFailure ) throw TestPartResult::kFatalFailure;
 		}
@@ -495,7 +495,7 @@ inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ DoubleNearPredFormat(const char*
 	return CmpHelperNearFloatingPoint(expr1, expr2, absc, val1, val2, abs_v);
 }
 template<typename T, typename A>
-static AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperNear(const char* expr1, const char* expr2, const char* absc
+inline AssertionResult IUTEST_ATTRIBUTE_UNUSED_ CmpHelperNear(const char* expr1, const char* expr2, const char* absc
 													, const T& val1, const T& val2, const A& abs_v)
 {
 	T diff = val1 > val2 ? val1 - val2 : val2 - val1;
