@@ -8,7 +8,7 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
@@ -27,6 +27,19 @@
  * @{
 */
 
+//! Library gǂ
+#ifndef IUTEST_HAS_LIB
+#  if	defined(IUTEST_NO_LIB)
+#    define IUTEST_HAS_LIB			0
+#  elif	defined(IUTEST_USE_LIB) || defined(IUTEST_AUTO_LINK)
+#    define IUTEST_HAS_LIB			1
+#  endif
+#endif
+
+#ifndef IUTEST_HAS_LIB
+#  define IUTEST_HAS_LIB			0
+#endif
+
 /**
  * @defgroup	IUTEST_CONFIG_OUTPUT	OUTPUT
  * @brief		o͊֌W CONFIG
@@ -53,10 +66,11 @@
 */
 
 #ifndef IUTEST_HAS_PARAM_METHOD_TEST
+//! p^CY֐R[eXggp\ǂ
 #  ifndef IUTEST_NO_VARIADIC_MACROS
-#    define IUTEST_HAS_PARAM_METHOD_TEST	1	//!< p^CY֐R[eXggp\ǂ
+#    define IUTEST_HAS_PARAM_METHOD_TEST	1
 #  else
-#    define IUTEST_HAS_PARAM_METHOD_TEST	0	//!< p^CY֐R[eXggp\ǂ
+#    define IUTEST_HAS_PARAM_METHOD_TEST	0
 #  endif
 #endif
 
@@ -87,6 +101,19 @@
 #  endif
 #endif
 
+#ifndef IUTEST_HAS_IGNORE_TEST
+/**
+ * @brief	RpCʂȂĂ悢eXg}Ngp\ǂ
+*/
+#  if	defined(_MSC_VER) && _MSC_VER > 1200
+#    define IUTEST_HAS_IGNORE_TEST	1
+#  elif	defined(__GNUC__) || defined(__clang__)
+#    define IUTEST_HAS_IGNORE_TEST	0
+#  else
+#    define IUTEST_HAS_IGNORE_TEST	0
+#  endif
+#endif
+
 #ifndef IUTEST_HAS_COMBINE
 //! ::iutest::Combine gp\ǂ
 #  if IUTEST_HAS_PARAM_TEST && IUTEST_HAS_TUPLE
@@ -106,35 +133,47 @@
 #endif
 
 #ifndef IUTEST_HAS_VARIADIC_VALUES
+//! ϒɑΉ ::iutest::Values gp\ǂ
 #  if IUTEST_HAS_PARAM_TEST && IUTEST_HAS_VARIADIC_TEMPLATES && IUTEST_HAS_TUPLE
-#    define IUTEST_HAS_VARIADIC_VALUES	1	//!< ϒɑΉ ::iutest::Values gp\ǂ
+#    define IUTEST_HAS_VARIADIC_VALUES	1
 #  else
-#    define IUTEST_HAS_VARIADIC_VALUES	0	//!< ϒɑΉ ::iutest::Values gp\ǂ
+#    define IUTEST_HAS_VARIADIC_VALUES	0
 #  endif
 #endif
 
 #ifndef IUTEST_HAS_VARIADIC_COMBINE
+//! ϒɑΉ ::iutest::Combine gp\ǂ
 #  if IUTEST_HAS_COMBINE && IUTEST_HAS_VARIADIC_TEMPLATES && IUTEST_HAS_TUPLE
-#    define IUTEST_HAS_VARIADIC_COMBINE	1	//!< ϒɑΉ ::iutest::Combine gp\ǂ
+#    define IUTEST_HAS_VARIADIC_COMBINE	1
 #  else
-#    define IUTEST_HAS_VARIADIC_COMBINE	0	//!< ϒɑΉ ::iutest::Combine gp\ǂ
+#    define IUTEST_HAS_VARIADIC_COMBINE	0
 #  endif
 #endif
 
 #ifndef IUTEST_HAS_VARIADIC_PAIRWISE
+//! ϒɑΉ ::iutest::Pairwise gp\ǂ
 #  if IUTEST_HAS_PAIRWISE && IUTEST_HAS_VARIADIC_TEMPLATES && IUTEST_HAS_TUPLE
-#    define IUTEST_HAS_VARIADIC_PAIRWISE	1	//!< ϒɑΉ ::iutest::Pairwise gp\ǂ
+#    define IUTEST_HAS_VARIADIC_PAIRWISE	1
 #  else
-#    define IUTEST_HAS_VARIADIC_PAIRWISE	0	//!< ϒɑΉ ::iutest::Pairwise gp\ǂ
+#    define IUTEST_HAS_VARIADIC_PAIRWISE	0
 #  endif
 #endif
 
-#ifndef IUTEST_THROW_ON_ASSERT_FAILURE
+#ifndef IUTEST_USE_THROW_ON_ASSERT_FAILURE
 /**
  * @brief	ASSERT }NŎsɗO throw ܂B
  * @note	Tu֐ɃAT[VLqĂA̎_ŃeXgf悤ɂȂ܂
 */
-#  define IUTEST_THROW_ON_ASSERT_FAILURE	0
+#  define IUTEST_USE_THROW_ON_ASSERT_FAILURE	0
+#endif
+
+#ifndef IUTEST_HAS_SPI_LAMBDA_SUPPORT
+//! spi }N lambda gĕϐɃANZX\ǂ
+#if IUTEST_HAS_LAMBDA
+#  define IUTEST_HAS_SPI_LAMBDA_SUPPORT		1
+#else
+#  define IUTEST_HAS_SPI_LAMBDA_SUPPORT		0
+#endif
 #endif
 
 #ifndef IUTEST_HAS_GENRAND
@@ -151,18 +190,20 @@
 #endif
 
 #ifndef IUTEST_HAS_PEEP_FUNC
+//! private o[֐ւ̃ANZX\ǂ
 #  if IUTEST_HAS_PEEP && IUTEST_EXPLICIT_INSTANTIATION_ACCESS_PRIVATE_MEMBER_FUNCTION
-#    define IUTEST_HAS_PEEP_FUNC	1	//!< private o[֐ւ̃ANZX\ǂ
+#    define IUTEST_HAS_PEEP_FUNC	1
 #  else
-#    define IUTEST_HAS_PEEP_FUNC	0	//!< private o[֐ւ̃ANZX\ǂ
+#    define IUTEST_HAS_PEEP_FUNC	0
 #  endif
 #endif
 
 #ifndef IUTEST_HAS_PEEP_STATIC_FUNC
+//! private static o[֐ւ̃ANZX\ǂ
 #  if IUTEST_HAS_PEEP && IUTEST_EXPLICIT_INSTANTIATION_ACCESS_PRIVATE_STATIC_MEMBER_FUNCTION
-#    define IUTEST_HAS_PEEP_STATIC_FUNC	1	//!< private static o[֐ւ̃ANZX\ǂ
+#    define IUTEST_HAS_PEEP_STATIC_FUNC	1
 #  else
-#    define IUTEST_HAS_PEEP_STATIC_FUNC	0	//!< private static o[֐ւ̃ANZX\ǂ
+#    define IUTEST_HAS_PEEP_STATIC_FUNC	0
 #  endif
 #endif
 
@@ -198,19 +239,34 @@
 */
 
 #ifndef IUTEST_HAS_CTIME
+//! time ֐gp\ǂ
 #  if	defined(IUTEST_OS_WINDOWS_MOBILE)
-#    define IUTEST_HAS_CTIME		0	//!< time ֐gp\ǂ
+#    define IUTEST_HAS_CTIME		0
 #  else
-#    define IUTEST_HAS_CTIME		1	//!< time ֐gp\ǂ
+#    define IUTEST_HAS_CTIME		1
+#  endif
+#endif
+
+//! gettimeofday ֐gp\ǂ
+#ifndef IUTEST_HAS_GETTIMEOFDAY
+#  if IUTEST_HAS_HDR_SYSTIME
+#    define IUTEST_HAS_GETTIMEOFDAY	1
 #  endif
 #endif
 
 #ifndef IUTEST_HAS_GETTIMEOFDAY
-#  define IUTEST_HAS_GETTIMEOFDAY	0	//!< gettimeofday ֐gp\ǂ
+#  define IUTEST_HAS_GETTIMEOFDAY	0
+#endif
+
+//! clock ֐gp\ǂ
+#ifndef IUTEST_HAS_CLOCK
+#  if defined(CLOCKS_PER_SEC)
+#    define IUTEST_HAS_CLOCK		1
+#  endif
 #endif
 
 #ifndef IUTEST_HAS_CLOCK
-#  define IUTEST_HAS_CLOCK			0	//!< clock ֐gp\ǂ
+#  define IUTEST_HAS_CLOCK			0
 #endif
 
 /**
@@ -224,13 +280,16 @@
  * @{
 */
 
-// other
 #ifndef IUTEST_HAS_STRINGSTREAM
 #  define IUTEST_HAS_STRINGSTREAM	1	//!< std::stringstream gp\ǂ
 #endif
 
-#ifndef IUTEST_USE_STRSTREAM
-#  define IUTEST_USE_STRSTREAM		0	//!< std::strstream gp\ǂ
+/**
+ * @brief	std::strstream gp\ǂ
+ * @note	IUTEST_HAS_STRINGSTREAM D悳܂
+*/
+#ifndef IUTEST_HAS_STRSTREAM
+#  define IUTEST_HAS_STRSTREAM		0
 #endif
 
 /**
@@ -281,6 +340,66 @@
  * @}
 */
 
+#define IUTEST_USE_LIB		//!< Cułgp
+#define IUTEST_AUTO_LINK	//!< CułgpAN
+
+#endif
+
+/**
+ * @}
+*/
+
+/**
+ * @private
+ * @{
+*/
+
+// include only
+#if IUTEST_HAS_LIB
+#  define IUTEST_IPP_INLINE
+#else
+#  define IUTEST_IPP_INLINE		inline
+#endif
+
+// auto link
+#if IUTEST_HAS_LIB && defined(IUTEST_AUTO_LINK)
+
+#if defined(_MSC_VER)
+
+#if defined(_MT) || defined(__MT__)
+#  if	defined(_DLL)
+#    define IUTEST_LIB_THREAD_OPT	"md"
+#  else
+#    define IUTEST_LIB_THREAD_OPT	"mt"
+#  endif
+#else
+#  define IUTEST_LIB_THREAD_OPT	""
+#endif
+
+#if		_MSC_VER == 1400
+#  define IUTEST_LIB_TOOLSET	"vc80"
+#elif	_MSC_VER == 1500
+#  define IUTEST_LIB_TOOLSET	"vc90"
+#elif	_MSC_VER == 1600
+#  define IUTEST_LIB_TOOLSET	"vc100"
+#elif	_MSC_VER == 1700
+#  define IUTEST_LIB_TOOLSET	"vc110"
+#else
+#  error unkown _MSC_VER.
+#endif
+
+#if		defined(_DEBUG)
+#  define IUTEST_LIB_RT_OPT		"d"
+#else
+#  define IUTEST_LIB_RT_OPT		""
+#endif
+
+#define IUTEST_LIB_NAME(name)	#name "-" IUTEST_LIB_TOOLSET "-" IUTEST_LIB_THREAD_OPT IUTEST_LIB_RT_OPT ".lib"
+
+#pragma comment(lib, IUTEST_LIB_NAME(libiutest) )
+
+#endif
+
 #endif
 
 /**
