@@ -8,7 +8,7 @@
  * @version		1.0
  *
  * @par			copyright
- * Copyright (C) 2011-2012, Takazumi Shirayanagi\n
+ * Copyright (C) 2011-2013, Takazumi Shirayanagi\n
  * The new BSD License is applied to this software.
  * see LICENSE
 */
@@ -35,12 +35,15 @@
  *			break_on_failure (bool)\n
  *			throw_on_failure (bool)\n
  *			catch_exceptions (bool)\n
+ *			catch_exceptions_each   (bool)\n
+ *			catch_exceptions_global (bool)\n
  *			random_seed (unsigned int)\n
  *			print_time (bool)\n
  *          color (string)\n
  *          filter (string)\n
  *          repeat (int)\n
  *			list_tests (bool)\n
+ *			file_location_style_msvc (bool)\n
 */
 #define IUTEST_FLAG(name)	IIUT_FLAG(name)
 
@@ -116,6 +119,7 @@ public:
 		CONSOLE_COLOR_OFF		= 0x00000200,	//!< FoOFF
 		CONSOLE_COLOR_ANSI		= 0x00000400,	//!< GXP[vV[PXŏo
 		PRINT_TIME				= 0x00001000,	//!< oߎԂ̏o
+		FILELOCATION_STYLE_MSVC	= 0x00002000,	//!< t@C/so̓X^C Visual Studio X^Cɂ
 		CATCH_EXCEPTION_EACH	= 0x00010000,	//!< O catch (TestInfo)
 		CATCH_EXCEPTION_GLOBAL	= 0x00020000,	//!< O catch (UnitTest)
 		CATCH_EXCEPTION			= 0x00030000,	//!< O catch 
@@ -126,7 +130,12 @@ public:
 		SHOW_FEATURE			= 0x80000000,	//!< @\̏o
 		MASK					= 0xFFFFFFFF,	//!< }XN
 
-		DEFAULT = CATCH_EXCEPTION|PRINT_TIME		//!< ftHg
+		//! ftHg
+#if defined(_MSC_VER)
+		DEFAULT = CATCH_EXCEPTION|PRINT_TIME|FILELOCATION_STYLE_MSVC
+#else
+		DEFAULT = CATCH_EXCEPTION|PRINT_TIME
+#endif
 	};
 
 private:
@@ -160,7 +169,7 @@ private:
 		Fragment(void) {}
 		Fragment(bool f)	{ SetFlag(KIND, f ? -1 : ~KIND); }
 		_Myt&	operator = (bool f)	{ SetFlag(KIND, f ? -1 : ~KIND); return *this; }
-		operator bool (void) const { return IsEnableFlag(KIND); }
+		IUTEST_CXX_EXPLICIT_CONVERSION operator bool (void) const { return IsEnableFlag(KIND); }
 	};
 
 private:
@@ -213,6 +222,8 @@ public:
 	typedef TestFlag::Fragment<TestFlag::CATCH_EXCEPTION_EACH>		catch_exceptions_each;
 	typedef TestFlag::Fragment<TestFlag::CATCH_EXCEPTION_GLOBAL>	catch_exceptions_global;
 
+	typedef TestFlag::Fragment<TestFlag::FILELOCATION_STYLE_MSVC>	file_location_style_msvc;
+
 	/**
 	 * @}
 	*/
@@ -484,24 +495,19 @@ private:
 	*/
 	static bool	ParseOutputOption(const char* option);
 
+	/**
+	 * @brief	IUTEST_FILE_LOCATION IvV̔
+	*/
+	static bool	ParseFileLocationOption(const char* option);
+
 	/**
 	 * @brief	yes IvV no IvV̔
-	 * @param [in]	option	= IvV
+	 * @param [in]	str		= R}hCi֐ȂŃIvV񕔕擾j
 	 * @param [in]	flag	= tO
 	 * @param [in]	def		= Ȃ̏ꍇ̃Iy[V
 	 * @return	
 	*/
-	static bool ParseYesNoFlagOption(const char* option, TestFlag::Kind flag, int def)
-	{
-		const char* str = ParseOptionSettingStr(option);
-		int yesno = str != NULL ? ParseYesNoOption(str) : def;
-		if( yesno < 0 )
-		{
-			return false;
-		}
-		TestFlag::SetFlag(flag, yesno ? TestFlag::MASK : ~(flag) );
-		return true;
-	}
+	static bool ParseYesNoFlagCommandLine(const char* str, TestFlag::Kind flag, int def);
 
 	/**
 	 * @brief	yes IvV no IvV̔
@@ -510,329 +516,25 @@ private:
 	 * @retval	0	= NO
 	 * @retval	> 0 = YES
 	*/
-	static int ParseYesNoOption(const char* option)
-	{
-		if( option == NULL ) return -1;
-		if( IsYes(option) ) return 1;
-		if( IsNo(option) ) return 0;
-		return -1;
-	}
+	static int ParseYesNoOption(const char* option);
 
 	/**
 	 * @brief	yes IvV
 	*/
-	static bool IsYes(const char* option)
-	{
-		if( detail::IsStringCaseEqual(option, "yes")
-			|| detail::IsStringCaseEqual(option, "y")
-			|| detail::IsStringCaseEqual(option, "on")
-			|| detail::IsStringCaseEqual(option, "true")
-			|| detail::IsStringCaseEqual(option, "t")
-			|| detail::IsStringEqual(option, "1") ) 
-		{
-			return true;
-		}
-		return false;
-	}
+	static bool IsYes(const char* option);
 	/**
 	 * @brief	no IvV
 	*/
-	static bool IsNo(const char* option)
-	{
-		if( detail::IsStringCaseEqual(option, "no")
-			|| detail::IsStringCaseEqual(option, "n")
-			|| detail::IsStringCaseEqual(option, "off")
-			|| detail::IsStringCaseEqual(option, "false")
-			|| detail::IsStringCaseEqual(option, "f")
-			|| detail::IsStringEqual(option, "0") ) 
-		{
-			return true;
-		}
-		return false;
-	}
+	static bool IsNo(const char* option);
 
 private:
 	friend class UnitTest;
 };
 
-inline bool TestEnv::ParseCommandLineElemA(const char* str)
-{
-	bool find = false;
-	if( *str == '-' )
-	{
-		find = true;
-		++str;
-		if( *str == '-' )
-		{
-			++str;
-			bool iuoption = false;
-			{
-				const char* const base_str = str;
-				if( *str == 'g' ) 
-				{
-					++str;
-					iuoption = true;
-				}
-				if(*str == 'i' && *(str+1) == 'u' )
-				{
-					str += 2;
-					iuoption = true;
-				}
-				const char option_prefix[] = "test_";
-				for( int i=0, size=sizeof(option_prefix)/sizeof(option_prefix[0])-1; i < size; ++i, ++str )
-				{
-					if( *str != option_prefix[i] )
-					{
-						iuoption = false;
-						str = base_str;
-						break;
-					}
-				}
-			}
-			if( iuoption )
-			{
-				// --iutest_*
-				if( strstr(str, "output") == str )
-				{
-					find = ParseOutputOption(ParseOptionSettingStr(str));
-				}
-				else if( detail::IsStringEqual(str, "list_tests") )
-				{
-					TestFlag::SetFlag(TestFlag::SHOW_TESTS_LIST);
-				}
-				else if( strstr(str, "color") == str )
-				{
-					find = ParseColorOption(ParseOptionSettingStr(str));
-				}
-				else if( detail::IsStringEqual(str, "shuffle") )
-				{
-					TestFlag::SetFlag(TestFlag::SHUFFLE_TESTS);
-				}
-				else if( strstr(str, "random_seed") == str )
-				{
-					const char* opt = ParseOptionSettingStr(str);
-					if( opt != NULL )
-					{
-						char* end = NULL;
-						long seed = strtol(opt, &end, 0);
-						init_random(static_cast<unsigned int>(seed));
-					}
-					else
-					{
-						find = false;
-					}
-				}
-				else if( detail::IsStringEqual(str, "also_run_disabled_tests") )
-				{
-					TestFlag::SetFlag(TestFlag::RUN_DISABLED_TESTS);
-				}
-				else if( strstr(str, "break_on_failure") == str )
-				{
-					find = ParseYesNoFlagOption(str, TestFlag::BREAK_ON_FAILURE, 1);
-				}
-				else if( strstr(str, "catch_exceptions") == str )
-				{
-					find = ParseYesNoFlagOption(str, TestFlag::CATCH_EXCEPTION, -1);
-				}
-				else if( strstr(str, "throw_on_failure") == str )
-				{
-					find = ParseYesNoFlagOption(str, TestFlag::THROW_ON_FAILURE, 1);
-				}
-				else if( strstr(str, "print_time") == str )
-				{
-					find = ParseYesNoFlagOption(str, TestFlag::PRINT_TIME, -1);
-				}
-				else if( strstr(str, "repeat") == str )
-				{
-					const char* opt = ParseOptionSettingStr(str);
-					if( opt != NULL )
-					{
-						char* end = NULL;
-						long count = strtol(opt, &end, 0);
-						set_repeat_count(static_cast<int>(count));
-					}
-					else
-					{
-						find = false;
-					}
-				}
-				else if( strstr(str, "filter") == str )
-				{
-					const char* opt = ParseOptionSettingStr(str);
-					if( opt != NULL )
-					{
-						set_test_filter(opt);
-					}
-				}
-				else
-				{
-					find = false;
-				}
-				if( !find )
-				{
-					// YIvVȂꍇ̓wv\
-					TestFlag::SetFlag(TestFlag::SHOW_HELP);
-				}
-			}
-			else if( detail::IsStringEqual(str, "help") )
-			{
-				TestFlag::SetFlag(TestFlag::SHOW_HELP);
-			}
-			else if( detail::IsStringEqual(str, "version") )
-			{
-				TestFlag::SetFlag(TestFlag::SHOW_VERSION);
-			}
-			else if( detail::IsStringEqual(str, "feature") )
-			{
-				TestFlag::SetFlag(TestFlag::SHOW_FEATURE);
-			}
-			else
-			{
-				find = false;
-			}
-		}
-		else
-		{
-			if( detail::IsStringEqual(str, "v") )
-			{
-				TestFlag::SetFlag(TestFlag::SHOW_VERSION);
-			}
-			else if( detail::IsStringEqual(str, "h")
-				|| detail::IsStringEqual(str, "?") )
-			{
-				TestFlag::SetFlag(TestFlag::SHOW_HELP);
-			}
-			else
-			{
-				find = false;
-			}
-		}
-	}
-	return find;
-}
-
-inline void TestEnv::LoadEnviromentVariable(void)
-{
-	{
-		int var = 0;
-		if( detail::GetEnvironmentInt("IUTEST_ALSO_RUN_DISABLED_TESTS", var) )
-		{
-			TestFlag::SetFlag(TestFlag::RUN_DISABLED_TESTS
-				, var ? TestFlag::MASK : ~(TestFlag::RUN_DISABLED_TESTS) );
-		}
-		if( detail::GetEnvironmentInt("IUTEST_SHUFFLE", var) )
-		{
-			TestFlag::SetFlag(TestFlag::SHUFFLE_TESTS
-				, var ? TestFlag::MASK : ~(TestFlag::SHUFFLE_TESTS) );
-		}
-		if( detail::GetEnvironmentInt("IUTEST_RANDOM_SEED", var) )
-		{
-			init_random((unsigned int)var);
-		}
-		if( detail::GetEnvironmentInt("IUTEST_CATCH_EXCEPTIONS", var) )
-		{
-			TestFlag::SetFlag(TestFlag::CATCH_EXCEPTION
-				, var ? TestFlag::MASK : ~(TestFlag::CATCH_EXCEPTION) );
-		}
-		if( detail::GetEnvironmentInt("IUTEST_BREAK_ON_FAILURE", var) )
-		{
-			TestFlag::SetFlag(TestFlag::BREAK_ON_FAILURE
-				, var ? TestFlag::MASK : ~(TestFlag::BREAK_ON_FAILURE) );
-		}
-		if( detail::GetEnvironmentInt("IUTEST_THROW_ON_FAILURE", var) )
-		{
-			TestFlag::SetFlag(TestFlag::THROW_ON_FAILURE
-				, var ? TestFlag::MASK : ~(TestFlag::THROW_ON_FAILURE) );
-		}
-		if( detail::GetEnvironmentInt("IUTEST_PRINT_TIME", var) )
-		{
-			TestFlag::SetFlag(TestFlag::PRINT_TIME
-				, var ? TestFlag::MASK : ~(TestFlag::PRINT_TIME) );
-		}
-		if( detail::GetEnvironmentInt("IUTEST_REPEAT", var) )
-		{
-			set_repeat_count(var);
-		}
-	}
-	{
-		char var[128] = {0};
-		if( detail::GetEnvironmentVariable("IUTEST_COLOR", var) )
-		{
-			ParseColorOption(var);
-		}
-	}
-	{
-		char path[260+32] = {0};
-		if( detail::GetEnvironmentVariable("IUTEST_OUTPUT", path) )
-		{
-			ParseOutputOption(path);
-		}
-		if( detail::GetEnvironmentVariable("IUTEST_FILTER", path) )
-		{
-			set_test_filter(path);
-		}
-	}
-}
-
-inline void	TestEnv::SetUp(void)
-{
-	unsigned int seed = get_random_seed();
-	if( seed == 0 )
-	{
-		seed = detail::GetIndefiniteValue();
-	}
-	get_vars().m_current_random_seed = seed;
-	genrand().init(seed);
-}
-
-inline 	bool TestEnv::ParseColorOption(const char* option)
-{
-	if( option == NULL ) return false;
-
-	if( IsYes(option) )
-	{
-		TestFlag::SetFlag(TestFlag::CONSOLE_COLOR_ON, ~TestFlag::CONSOLE_COLOR_OFF);
-	}
-	else if( IsNo(option) )
-	{
-		TestFlag::SetFlag(TestFlag::CONSOLE_COLOR_OFF, ~TestFlag::CONSOLE_COLOR_ON);
-	}
-	else if( detail::IsStringCaseEqual(option, "auto") )
-	{
-		// auto
-		TestFlag::SetFlag(0, ~(TestFlag::CONSOLE_COLOR_ON|TestFlag::CONSOLE_COLOR_OFF));
-	}
-	else if( detail::IsStringCaseEqual(option, "ansi") )
-	{
-		// ansi
-		TestFlag::SetFlag(TestFlag::CONSOLE_COLOR_ON|TestFlag::CONSOLE_COLOR_ANSI, ~TestFlag::CONSOLE_COLOR_OFF);
-	}
-	else 
-	{
-		return false;
-	}
-	return true;
-}
-
-inline bool	TestEnv::ParseOutputOption(const char* option)
-{
-	if( option == NULL ) return false;
-	if( strstr(option, "xml") != NULL )
-	{
-		TestFlag::SetFlag(TestFlag::OUTPUT_XML_REPORT);
-	}
-	else
-	{
-		return false;
-	}
-	const char* file = strchr(option+3, ':');
-	if( file != NULL )
-	{
-		get_vars().m_report_file = file+1;
-	}
-	return true;
-}
-
 }	// end of namespace iutest
 
+#if !IUTEST_HAS_LIB
+#  include "impl/iutest_env.ipp"
+#endif
+
 #endif
